"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "useListItem_unstable", {
    enumerable: true,
    get: function() {
        return useListItem_unstable;
    }
});
const _interop_require_wildcard = require("@swc/helpers/_/_interop_require_wildcard");
const _reactaria = require("@fluentui/react-aria");
const _reactutilities = require("@fluentui/react-utilities");
const _react = /*#__PURE__*/ _interop_require_wildcard._(require("react"));
const _listContext = require("../List/listContext");
const DEFAULT_ROOT_EL_TYPE = 'li';
function validateProperElementTypes(parentRenderedAs, renderedAs) {
    if (process.env.NODE_ENV === 'production') {
        return;
    }
    if (renderedAs === 'div' && parentRenderedAs !== 'div') {
        throw new Error('ListItem cannot be rendered as a div when its parent is not a div.');
    }
    if (renderedAs === 'li' && parentRenderedAs === 'div') {
        throw new Error('ListItem cannot be rendered as a li when its parent is a div.');
    }
}
function validateNavigableWhenOnClickPresent(navigable, onClick) {
    if (process.env.NODE_ENV === 'production') {
        return;
    }
    if (onClick && !navigable) {
        throw new Error('ListItem must be navigable when onClick is present. Set navigable={true} on the List.');
    }
}
const useListItem_unstable = (props, ref)=>{
    const id = (0, _reactutilities.useId)('listItem');
    const { value = id, truncateHeader, truncateContent, onClick, onKeyDown, onKeyUp } = props;
    const navigable = (0, _listContext.useListContext_unstable)((ctx)=>ctx.navigable);
    const toggleItem = (0, _listContext.useListContext_unstable)((ctx)=>{
        var _ctx_selection;
        return (_ctx_selection = ctx.selection) === null || _ctx_selection === void 0 ? void 0 : _ctx_selection.toggleItem;
    });
    const isSelectionEnabled = (0, _listContext.useListContext_unstable)((ctx)=>!!ctx.selection);
    const isSelected = (0, _listContext.useListContext_unstable)((ctx)=>{
        var _ctx_selection;
        return (_ctx_selection = ctx.selection) === null || _ctx_selection === void 0 ? void 0 : _ctx_selection.isSelected(value);
    });
    const truncateHeaderOnList = (0, _listContext.useListContext_unstable)((ctx)=>ctx.truncateHeader);
    const truncateContentOnList = (0, _listContext.useListContext_unstable)((ctx)=>ctx.truncateContent);
    const parentRenderedAs = (0, _listContext.useListContext_unstable)((ctx)=>ctx.as);
    const renderedAs = props.as || DEFAULT_ROOT_EL_TYPE;
    validateProperElementTypes(parentRenderedAs, renderedAs);
    validateNavigableWhenOnClickPresent(navigable, onClick);
    const handleClick = (0, _reactutilities.useEventCallback)((e)=>{
        onClick === null || onClick === void 0 ? void 0 : onClick(e);
        if (!isSelectionEnabled || e.defaultPrevented) {
            return;
        }
        toggleItem === null || toggleItem === void 0 ? void 0 : toggleItem(e, value);
    });
    // avoid passing empty onClick to prevent items unnecessary being narrated as clickable
    // see https://github.com/microsoft/fluentui/issues/20658
    const passClickHandler = !!onClick || isSelectionEnabled;
    const clickHandlerProps = {
        onClick: passClickHandler ? handleClick : undefined,
        onKeyDown: onKeyDown,
        onKeyUp: onKeyUp
    };
    // This will give us the onKeyDown and onKeyUp props for Enter and Space
    const ariaButtonProps = (0, _reactaria.useARIAButtonProps)('div', clickHandlerProps);
    // v0 ListItem adds keyboard handling only for navigable or selectable items
    const buttonProps = navigable || isSelectionEnabled ? ariaButtonProps : clickHandlerProps;
    const root = _reactutilities.slot.always((0, _reactutilities.getIntrinsicElementProps)(DEFAULT_ROOT_EL_TYPE, {
        ref: ref,
        tabIndex: navigable || isSelectionEnabled ? 0 : undefined,
        role: navigable ? 'menuitem' : 'listitem',
        id: String(value),
        ...isSelectionEnabled && {
            role: 'option',
            'aria-selected': isSelected
        },
        ...props,
        onKeyDown: buttonProps.onKeyDown,
        onKeyUp: buttonProps.onKeyUp,
        onClick: buttonProps.onClick
    }), {
        elementType: DEFAULT_ROOT_EL_TYPE
    });
    const state = {
        components: {
            root: DEFAULT_ROOT_EL_TYPE,
            media: 'div',
            header: 'div',
            contentWrapper: 'div',
            headerMedia: 'div',
            contentMedia: 'div',
            endMedia: 'div'
        },
        root,
        navigable,
        selectable: isSelectionEnabled,
        selected: isSelected,
        media: _reactutilities.slot.optional(props.media, {
            elementType: 'div'
        }),
        header: _reactutilities.slot.optional(props.header, {
            elementType: 'div'
        }),
        contentWrapper: _reactutilities.slot.optional(props.contentWrapper, {
            elementType: 'div',
            renderByDefault: true
        }),
        headerMedia: _reactutilities.slot.optional(props.headerMedia, {
            elementType: 'div'
        }),
        contentMedia: _reactutilities.slot.optional(props.contentMedia, {
            elementType: 'div'
        }),
        endMedia: _reactutilities.slot.optional(props.endMedia, {
            elementType: 'div'
        }),
        truncateHeader: truncateHeader !== null && truncateHeader !== void 0 ? truncateHeader : truncateHeaderOnList,
        truncateContent: truncateContent !== null && truncateContent !== void 0 ? truncateContent : truncateContentOnList
    };
    return state;
};
