import { Button, mergeClasses } from '@fluentui/react-components';
import * as React from 'react';
import { useAttachmentActionStyles } from './AttachmentAction.styles';
export const attachmentActionClassName = 'fui-AttachmentAction';
export const AttachmentAction = /*#__PURE__*/ React.forwardRef((props, ref)=>{
    const { className, disabled, disabledFocusable, children, onClick, onKeyUp, onKeyDown, ...rest } = props;
    const classes = useAttachmentActionStyles();
    const handleClick = React.useCallback((e)=>{
        e.stopPropagation();
        e.preventDefault();
        onClick === null || onClick === void 0 ? void 0 : onClick(e);
    }, [
        onClick
    ]);
    const handleKeyUp = React.useCallback((e)=>{
        if (e.key === 'Enter' || e.key === ' ') {
            e.stopPropagation();
        }
        onKeyUp === null || onKeyUp === void 0 ? void 0 : onKeyUp(e);
    }, [
        onKeyUp
    ]);
    const handleKeyDown = React.useCallback((e)=>{
        if (e.key === 'Enter' || e.key === ' ') {
            e.stopPropagation();
        }
        onKeyDown === null || onKeyDown === void 0 ? void 0 : onKeyDown(e);
    }, [
        onKeyDown
    ]);
    return /*#__PURE__*/ React.createElement(Button, {
        ref: ref,
        className: mergeClasses(attachmentActionClassName, classes.root, (disabled || disabledFocusable) && classes.disabled, className),
        appearance: "transparent",
        disabled: disabled,
        disabledFocusable: disabledFocusable,
        onClick: handleClick,
        onKeyDown: handleKeyDown,
        onKeyUp: handleKeyUp,
        ...rest
    }, children);
});
AttachmentAction.displayName = 'AttachmentAction';
