import { mergeClasses } from '@fluentui/react-components';
import * as React from 'react';
import { useFlexStyles } from './Flex.styles';
export const flexClassName = 'fui-Flex';
export const Flex = /*#__PURE__*/ React.forwardRef((props, ref)=>{
    const { children, column, fill, gap, hAlign, inline, padding, space, vAlign, wrap, className, ...rest } = props;
    const classes = useFlexStyles();
    const classMaps = React.useMemo(()=>({
            alignItems: {
                start: classes.alignItemsFlexStart,
                center: classes.alignItemsCenter,
                end: classes.alignItemsFlexEnd,
                stretch: classes.alignItemsCenter
            },
            justifyContent: {
                start: classes.justifyContentFlexStart,
                center: classes.justifyContentCenter,
                end: classes.justifyContentFlexEnd,
                stretch: classes.justifyContentStretch
            },
            justifyContentSpace: {
                around: classes.justifyContentSpaceAround,
                between: classes.justifyContentSpaceBetween,
                evenly: classes.justifyContentSpaceEvenly
            },
            gapForColumnFlex: {
                'gap.smaller': classes.gapForColumnFlexSmaller,
                'gap.small': classes.gapForColumnFlexSmall,
                'gap.medium': classes.gapForColumnFlexMedium,
                'gap.large': classes.gapForColumnFlexLarge
            },
            gapRow: {
                'gap.smaller': classes.gapForRowFlexSmaller,
                'gap.small': classes.gapForRowFlexSmall,
                'gap.medium': classes.gapForRowFlexMedium,
                'gap.large': classes.gapForRowFlexLarge
            },
            paddings: {
                'padding.medium': classes.paddingMedium
            }
        }), [
        classes
    ]);
    const flexClasses = mergeClasses(flexClassName, classes.flex, inline && classes.inline, column && classes.column, hAlign && (column ? classMaps.alignItems[hAlign] : classMaps.justifyContent[hAlign]), vAlign && (column ? classMaps.justifyContent[vAlign] : classMaps.alignItems[vAlign]), space && classMaps.justifyContentSpace[space], wrap && classes.wrap, fill && classes.fill, gap && (column ? classMaps.gapForColumnFlex[gap] : classMaps.gapRow[gap]), padding && classMaps.paddings[padding], className);
    const content = React.Children.map(children, (child)=>{
        var _child_type;
        // @ts-expect-error __isFlexItem is added to the React type property by N*
        const isFlexItemElement = child === null || child === void 0 ? void 0 : (_child_type = child.type) === null || _child_type === void 0 ? void 0 : _child_type.__isFlexItem;
        return isFlexItemElement ? /*#__PURE__*/ React.cloneElement(child, {
            flexDirection: column ? 'column' : 'row'
        }) : child;
    });
    return /*#__PURE__*/ React.createElement("div", {
        ref: ref,
        className: flexClasses,
        ...rest
    }, content);
});
Flex.displayName = 'Flex';
