import { mergeClasses, useMergedRefs } from '@fluentui/react-components';
import * as React from 'react';
import { useVideoStyles } from './Video.styles';
export const videoClassName = 'fui-Video';
export const Video = /*#__PURE__*/ React.forwardRef((props, ref)=>{
    'use no memo';
    const { className, muted, ...rest } = props;
    const videoRef = React.useRef();
    const classes = useVideoStyles();
    React.useEffect(()=>{
        // this is a workaround for a potential memory leak in Chromium which retains a Detached HTMLVideoElement when <video autoplay> is unmounted
        // https://bugs.chromium.org/p/chromium/issues/detail?id=969049
        return ()=>{
            if (videoRef === null || videoRef === void 0 ? void 0 : videoRef.current) {
                // we want to perform the cleanup on the latest element rendered
                // eslint-disable-next-line react-hooks/exhaustive-deps
                videoRef.current.src = '';
            }
        };
    }, [
        videoRef
    ]);
    React.useEffect(()=>{
        // React doesn't guarantee that props will be set:
        // https://github.com/facebook/react/issues/10389
        if (videoRef.current) {
            videoRef.current.muted = !!muted;
        }
    }, [
        muted
    ]);
    return /*#__PURE__*/ React.createElement("video", {
        ref: useMergedRefs(ref, videoRef),
        role: "application",
        className: mergeClasses(videoClassName, classes.root, className),
        controls: true,
        autoPlay: false,
        muted: muted,
        ...rest
    });
});
Video.displayName = 'Video';
